==> rrdbelt-0.0.1.tar.gz: rrdbelt-0.0.1/util/cpuinfo.sh <==
#!/bin/sh
######################################################################
##                                                                  ##
##                RRDBELT Ver 0.0.1                                 ##
##                                                                  ##
##  Author  : Jinoos Lee (jinoos(at)jinoos.com)                     ##
##  DATE    : 2003.06.05                                            ##
##  LASTMOD : 2003.06.17                                            ##
##                                                                  ##
##  Copyright follow GPL license                                    ##
##                                                                  ##
##  RRDBELT PHP SNMP ̿ ټ  ¸ Ͽ ׷  ##
##  ǥϴ RRDTOOL ο Frontend Դϴ.                  ##
##                                                                  ##
######################################################################
##                                                                  ##
##  Cpu info script                                                 ##
##                                                                  ##
######################################################################

f_cpu1()
{
    echo -n `uptime|sed 's/,//g'|awk '{print $10}'`
}
f_cpu5()
{
    echo -n `uptime|sed 's/,//g'|awk '{print $11}'`
}
f_cpu15()
{
    echo -n `uptime|sed 's/,//g'|awk '{print $12}'`
}

if [ "${1}" = "1" ]; then
    f_cpu1
elif [ "${1}" = "5" ]; then
    f_cpu5
elif [ "${1}" = "15" ]; then
    f_cpu15
else
    echo ""
    echo "Usage : cpuinfo.sh [1|10|15]"
    echo ""
fi

exit 0

==> rrdbelt-0.0.3.tar.gz: rrdbelt-0.0.3/util/cpuinfo.sh <==
#!/bin/sh
######################################################################
##                                                                  ##
##                RRDBELT                                           ##
##                                                                  ##
##  Author  : Jinoos Lee (jinoos(at)jinoos.com)                     ##
##  DATE    : 2003.06.05                                            ##
##  LASTMOD : 2003.06.18                                            ##
##                                                                  ##
##  Copyright follow GPL license                                    ##
##                                                                  ##
##  RRDBELT PHP SNMP ̿ ټ  ¸ Ͽ ׷  ##
##  ǥϴ RRDTOOL ο Frontend Դϴ.                  ##
##                                                                  ##
######################################################################
##                                                                  ##
##  Cpu info script                                                 ##
##                                                                  ##
######################################################################

f_cpu1()
{
    echo -n `uptime|sed 's/,//g' | sed 's/[a-z]//g' | awk '{print $6}'`
}

f_cpu5()
{
    echo -n `uptime|sed 's/,//g' | sed 's/[a-z]//g' | awk '{print $7}'`
}
f_cpu15()
{
    echo -n `uptime|sed 's/,//g' | sed 's/[a-z]//g' | awk '{print $8}'`
}

if [ "${1}" = "1" ]; then
    f_cpu1
elif [ "${1}" = "5" ]; then
    f_cpu5
elif [ "${1}" = "15" ]; then
    f_cpu15
else
    echo ""
    echo "Usage : cpuinfo.sh [1|5|15]"
    echo ""
fi

exit 0
